django-oauth2-provider
======================

*django-oauth2-provider* is a Django application that provides
customizable OAuth2\_ authentication for your Django projects.

`Documentation <http://readthedocs.org/docs/django-oauth2-provider/en/latest/>`_
